@@ -1,16 +1,16 @@
 package HTML::Widgets::NavMenu;
-$HTML::Widgets::NavMenu::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::VERSION = '1.0901';
 use strict;
 use warnings;
 
 use 5.012;
 
 package HTML::Widgets::NavMenu::Error;
-$HTML::Widgets::NavMenu::Error::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::Error::VERSION = '1.0901';
 use parent "HTML::Widgets::NavMenu::Object";
 
 package HTML::Widgets::NavMenu::Error::Redirect;
-$HTML::Widgets::NavMenu::Error::Redirect::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::Error::Redirect::VERSION = '1.0901';
 use strict;
 use vars qw(@ISA);
 @ISA = ("HTML::Widgets::NavMenu::Error");
@@ -26,7 +26,7 @@ sub CGIpm_perform_redirect
 }
 
 package HTML::Widgets::NavMenu::NodeDescription;
-$HTML::Widgets::NavMenu::NodeDescription::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::NodeDescription::VERSION = '1.0901';
 use strict;
 
 use parent qw(HTML::Widgets::NavMenu::Object);
@@ -48,13 +48,13 @@ sub _init
 1;
 
 package HTML::Widgets::NavMenu::LeadingPath::Component;
-$HTML::Widgets::NavMenu::LeadingPath::Component::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::LeadingPath::Component::VERSION = '1.0901';
 use vars qw(@ISA);
 
 @ISA = (qw(HTML::Widgets::NavMenu::NodeDescription));
 
 package HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive;
-$HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive::VERSION = '1.0900';
+$HTML::Widgets::NavMenu::Iterator::GetCurrentlyActive::VERSION = '1.0901';
 use parent 'HTML::Widgets::NavMenu::Iterator::Base';
 
 __PACKAGE__->mk_acc_ref(
@@ -780,6 +780,21 @@ sub render
         { %args, _iter_method => '_get_nav_menu_traverser', } );
 }
 
+sub _is_top_coords
+{
+    my ( $self, $coords ) = @_;
+
+    return (
+        defined($coords)
+        ? (
+              ( @$coords == 0 ) ? 1
+            : ( @$coords == 1 ) ? ( $coords->[0] == 0 )
+            :                     ''
+            )
+        : 1
+    );
+}
+
 sub _render_generic
 {
     my $self = shift;
@@ -809,7 +824,8 @@ sub _render_generic
     {
         # This is so we would avoid coordinates that point to the
         # root ($coords == []).
-        if ( defined($coords) && @$coords == 0 )
+        if (    $self->_is_top_coords( $self->_current_coords() )
+            and $self->_is_top_coords($coords) )
         {
             undef($coords);
         }
@@ -846,7 +862,7 @@ HTML::Widgets::NavMenu - A Perl Module for Generating HTML Navigation Menus
 
 =head1 VERSION
 
-version 1.0900
+version 1.0901
 
 =head1 SYNOPSIS
 
